package com.goldencode.testcases.dmo.p2j_test.impl;

import java.io.Serializable;
import java.util.*;
import com.goldencode.p2j.persist.*;
import com.goldencode.p2j.util.*;
import com.goldencode.testcases.dmo.p2j_test.*;

/**
 * Data Model Object corresponding with table <code>p2j_test.vehicle</code>
 * (previously <code>p2j_test.vehicle</code>).
 */
@LegacyTable(name = "vehicle")
@LegacyIndexes(
{
   @LegacyIndex(name = "pi-make-model", converted = "vehicle_pi_make_model",  primary = true),
   @LegacyIndex(name = "si-vin", converted = "vehicle_si_vin")
})
public class VehicleImpl
implements Serializable,
           Persistable,
           Vehicle
{
   /** Surrogate primary key */
   private Long id = null;

   /** Make; Manufacturer */
   @LegacyField( fieldId = 1 , name = "make" , format = "x(12)" , label = "Make" , mandatory = true)
   private final character make;

   /** Model; Vehicle model name */
   @LegacyField( fieldId = 2 , name = "model" , format = "x(16)" , label = "Model" , mandatory = true)
   private final character model;

   /** Number of axles; Number of axles */
   @LegacyField( fieldId = 3 , name = "axles" , format = ">,>>>,>>9" , initial = "2" , label = "Number of axles")
   private final integer axles;

   /** Exterior; Exterior color */
   @LegacyField( fieldId = 4 , name = "ext-color" , format = "x(16)" , label = "Exterior")
   private final character extColor;

   /** VIN; Vehicle Identification Number */
   @LegacyField( fieldId = 5 , name = "vin-number" , format = "xxxx-xxxx-xxxx" , label = "VIN" , mandatory = true)
   private final character vinNumber;

   /** Options; Optional features */
   @LegacyField( fieldId = 6 , name = "options,1" , label = "Options" , index = 1)
   private final character options1;

   /** Options; Optional features */
   @LegacyField( fieldId = 7 , name = "options,2" , label = "Options" , index = 2)
   private final character options2;

   /** Options; Optional features */
   @LegacyField( fieldId = 8 , name = "options,3" , label = "Options" , index = 3)
   private final character options3;

   /** Options; Optional features */
   @LegacyField( fieldId = 9 , name = "options,4" , label = "Options" , index = 4)
   private final character options4;

   /** Options; Optional features */
   @LegacyField( fieldId = 10 , name = "options,5" , label = "Options" , index = 5)
   private final character options5;

   /** Options; Optional features */
   @LegacyField( fieldId = 11 , name = "options,6" , label = "Options" , index = 6)
   private final character options6;

   /** Options; Optional features */
   @LegacyField( fieldId = 12 , name = "options,7" , label = "Options" , index = 7)
   private final character options7;

   /** Options; Optional features */
   @LegacyField( fieldId = 13 , name = "options,8" , label = "Options" , index = 8)
   private final character options8;

   /** Options; Optional features */
   @LegacyField( fieldId = 14 , name = "options,9" , label = "Options" , index = 9)
   private final character options9;

   /** Options; Optional features */
   @LegacyField( fieldId = 15 , name = "options,10" , format = "x(32)" , label = "Options" , index = 10)
   private final character options10;

   /**
    * Default constructor.
    */
   public VehicleImpl()
   {
      make = new character("");
      model = new character("");
      axles = new integer(2);
      extColor = new character("");
      vinNumber = new character("");
      options1 = new character("");
      options2 = new character("");
      options3 = new character("");
      options4 = new character("");
      options5 = new character("");
      options6 = new character("");
      options7 = new character("");
      options8 = new character("");
      options9 = new character("");
      options10 = new character("");
   }

   /**
    * Make a deep copy of the current DMO instance and return it.
    * 
    * @return  A new instance of this class whose data is identical to that of
    *          this instance.
    */
   public Undoable deepCopy()
   {
      Undoable copy = new VehicleImpl();
      copy.assign(this);
      return copy;
   }

   /**
    * Modify the contained data of the instance to copy the instance data from
    * the given, backup instance.
    * 
    * @param   old
    *          The backup instance from which to copy data.
    */
   public void assign(Undoable old)
   {
      VehicleImpl from = (VehicleImpl) old;
      setId(from.getId());
      setMake(from.getMake());
      setModel(from.getModel());
      setAxles(from.getAxles());
      setExtColor(from.getExtColor());
      setVinNumber(from.getVinNumber());
      setOptions1(from.getOptions1());
      setOptions2(from.getOptions2());
      setOptions3(from.getOptions3());
      setOptions4(from.getOptions4());
      setOptions5(from.getOptions5());
      setOptions6(from.getOptions6());
      setOptions7(from.getOptions7());
      setOptions8(from.getOptions8());
      setOptions9(from.getOptions9());
      setOptions10(from.getOptions10());
   }

   /**
    * Getter: Surrogate primary key
    * 
    * @return  Primary key
    */
   public Long getId()
   {
      return id;
   }

   /**
    * Setter: Surrogate primary key
    * 
    * @param   id
    *          Primary key
    */
   public void setId(Long id)
   {
      this.id = id;
   }

   /**
    * Getter: Manufacturer
    * 
    * @return  Make
    */
   public character getMake()
   {
      return (new character(make));
   }

   /**
    * Setter: Manufacturer
    * 
    * @param   make
    *          Make
    */
   public void setMake(Text make)
   {
      this.make.assign(make, true);
   }

   /**
    * Getter: Vehicle model name
    * 
    * @return  Model
    */
   public character getModel()
   {
      return (new character(model));
   }

   /**
    * Setter: Vehicle model name
    * 
    * @param   model
    *          Model
    */
   public void setModel(Text model)
   {
      this.model.assign(model, true);
   }

   /**
    * Getter: Number of axles
    * 
    * @return  Number of axles
    */
   public integer getAxles()
   {
      return (new integer(axles));
   }

   /**
    * Setter: Number of axles
    * 
    * @param   axles
    *          Number of axles
    */
   public void setAxles(NumberType axles)
   {
      this.axles.assign(axles, true);
   }

   /**
    * Getter: Exterior color
    * 
    * @return  Exterior
    */
   public character getExtColor()
   {
      return (new character(extColor));
   }

   /**
    * Setter: Exterior color
    * 
    * @param   extColor
    *          Exterior
    */
   public void setExtColor(Text extColor)
   {
      this.extColor.assign(extColor, true);
   }

   /**
    * Getter: Vehicle Identification Number
    * 
    * @return  VIN
    */
   public character getVinNumber()
   {
      return (new character(vinNumber));
   }

   /**
    * Setter: Vehicle Identification Number
    * 
    * @param   vinNumber
    *          VIN
    */
   public void setVinNumber(Text vinNumber)
   {
      this.vinNumber.assign(vinNumber, true);
   }

   /**
    * Getter: Optional features
    * 
    * @return  Options
    */
   public character getOptions1()
   {
      return (new character(options1));
   }

   /**
    * Setter: Optional features
    * 
    * @param   options1
    *          Options
    */
   public void setOptions1(Text options1)
   {
      this.options1.assign(options1, true);
   }

   /**
    * Getter: Optional features
    * 
    * @return  Options
    */
   public character getOptions2()
   {
      return (new character(options2));
   }

   /**
    * Setter: Optional features
    * 
    * @param   options2
    *          Options
    */
   public void setOptions2(Text options2)
   {
      this.options2.assign(options2, true);
   }

   /**
    * Getter: Optional features
    * 
    * @return  Options
    */
   public character getOptions3()
   {
      return (new character(options3));
   }

   /**
    * Setter: Optional features
    * 
    * @param   options3
    *          Options
    */
   public void setOptions3(Text options3)
   {
      this.options3.assign(options3, true);
   }

   /**
    * Getter: Optional features
    * 
    * @return  Options
    */
   public character getOptions4()
   {
      return (new character(options4));
   }

   /**
    * Setter: Optional features
    * 
    * @param   options4
    *          Options
    */
   public void setOptions4(Text options4)
   {
      this.options4.assign(options4, true);
   }

   /**
    * Getter: Optional features
    * 
    * @return  Options
    */
   public character getOptions5()
   {
      return (new character(options5));
   }

   /**
    * Setter: Optional features
    * 
    * @param   options5
    *          Options
    */
   public void setOptions5(Text options5)
   {
      this.options5.assign(options5, true);
   }

   /**
    * Getter: Optional features
    * 
    * @return  Options
    */
   public character getOptions6()
   {
      return (new character(options6));
   }

   /**
    * Setter: Optional features
    * 
    * @param   options6
    *          Options
    */
   public void setOptions6(Text options6)
   {
      this.options6.assign(options6, true);
   }

   /**
    * Getter: Optional features
    * 
    * @return  Options
    */
   public character getOptions7()
   {
      return (new character(options7));
   }

   /**
    * Setter: Optional features
    * 
    * @param   options7
    *          Options
    */
   public void setOptions7(Text options7)
   {
      this.options7.assign(options7, true);
   }

   /**
    * Getter: Optional features
    * 
    * @return  Options
    */
   public character getOptions8()
   {
      return (new character(options8));
   }

   /**
    * Setter: Optional features
    * 
    * @param   options8
    *          Options
    */
   public void setOptions8(Text options8)
   {
      this.options8.assign(options8, true);
   }

   /**
    * Getter: Optional features
    * 
    * @return  Options
    */
   public character getOptions9()
   {
      return (new character(options9));
   }

   /**
    * Setter: Optional features
    * 
    * @param   options9
    *          Options
    */
   public void setOptions9(Text options9)
   {
      this.options9.assign(options9, true);
   }

   /**
    * Getter: Optional features
    * 
    * @return  Options
    */
   public character getOptions10()
   {
      return (new character(options10));
   }

   /**
    * Setter: Optional features
    * 
    * @param   options10
    *          Options
    */
   public void setOptions10(Text options10)
   {
      this.options10.assign(options10, true);
   }

   /**
    * Getter: Indexed getter
    * 
    * @return  options
    */
   @CustomExtentProperty(name = "options")
   @CustomExtentMethods(
   {
      @CustomExtentMethod(name = "getOptions1"),
      @CustomExtentMethod(name = "getOptions2"),
      @CustomExtentMethod(name = "getOptions3"),
      @CustomExtentMethod(name = "getOptions4"),
      @CustomExtentMethod(name = "getOptions5"),
      @CustomExtentMethod(name = "getOptions6"),
      @CustomExtentMethod(name = "getOptions7"),
      @CustomExtentMethod(name = "getOptions8"),
      @CustomExtentMethod(name = "getOptions9"),
      @CustomExtentMethod(name = "getOptions10")
   })
   public Text getOptions(int index)
   {
      throw new UnsupportedOperationException();
   }

   /**
    * Setter: Indexed setter
    * 
    * @param   options,10
    *          options
    */
   @CustomExtentProperty(name = "options")
   @CustomExtentMethods(
   {
      @CustomExtentMethod(name = "setOptions1"),
      @CustomExtentMethod(name = "setOptions2"),
      @CustomExtentMethod(name = "setOptions3"),
      @CustomExtentMethod(name = "setOptions4"),
      @CustomExtentMethod(name = "setOptions5"),
      @CustomExtentMethod(name = "setOptions6"),
      @CustomExtentMethod(name = "setOptions7"),
      @CustomExtentMethod(name = "setOptions8"),
      @CustomExtentMethod(name = "setOptions9"),
      @CustomExtentMethod(name = "setOptions10")
   })
   public void setOptions(int index, Text options)
   {
      throw new UnsupportedOperationException();
   }

   /**
    * Getter: Indexed getter
    * 
    * @return  options
    */
   @CustomExtentProperty(name = "options")
   @CustomExtentMethods(
   {
      @CustomExtentMethod(name = "getOptions1"),
      @CustomExtentMethod(name = "getOptions2"),
      @CustomExtentMethod(name = "getOptions3"),
      @CustomExtentMethod(name = "getOptions4"),
      @CustomExtentMethod(name = "getOptions5"),
      @CustomExtentMethod(name = "getOptions6"),
      @CustomExtentMethod(name = "getOptions7"),
      @CustomExtentMethod(name = "getOptions8"),
      @CustomExtentMethod(name = "getOptions9"),
      @CustomExtentMethod(name = "getOptions10")
   })
   public Text getOptions(NumberType index)
   {
      throw new UnsupportedOperationException();
   }

   /**
    * Setter: Indexed setter
    * 
    * @param   options,10
    *          options
    */
   @CustomExtentProperty(name = "options")
   @CustomExtentMethods(
   {
      @CustomExtentMethod(name = "setOptions1"),
      @CustomExtentMethod(name = "setOptions2"),
      @CustomExtentMethod(name = "setOptions3"),
      @CustomExtentMethod(name = "setOptions4"),
      @CustomExtentMethod(name = "setOptions5"),
      @CustomExtentMethod(name = "setOptions6"),
      @CustomExtentMethod(name = "setOptions7"),
      @CustomExtentMethod(name = "setOptions8"),
      @CustomExtentMethod(name = "setOptions9"),
      @CustomExtentMethod(name = "setOptions10")
   })
   public void setOptions(NumberType index, Text options)
   {
      throw new UnsupportedOperationException();
   }

   /**
    * Report number of list elements for options
    * 
    * @return  Number of list elements for options
    */
   public integer sizeOptions()
   {
      return (new integer(10));
   }
}
